@@ -37,6 +37,7 @@ MANDATES_ROOT = COVID_19 / 'mandates'
 MASK_USE_OUTPUT_ROOT = COVID_19 / 'mask-use-outputs'
 MOBILITY_COVARIATES_OUTPUT_ROOT = COVID_19 / 'mobility-covariate'
 MOBILITY_COVARIATES_GPR_OUTPUT_ROOT = MOBILITY_COVARIATES_OUTPUT_ROOT / 'gpr_outputs'
+MODEL_COMPARISON_INPUTS_ROOT = COVID_19 / 'model-comparison-inputs'
 MODEL_INPUTS_ROOT = COVID_19 / 'model-inputs'
 MORTALITY_AGE_PATTERN_ROOT = COVID_19 / 'mortality-age-pattern'
 PAST_INFECTIONS_ROOT = COVID_19 / 'past-infections'
@@ -58,9 +59,9 @@ SYMPTOM_SURVEY_ROOT = COVID_19 / 'symptom-survey-data'
 TESTING_OUTPUT_ROOT = COVID_19 / 'testing-outputs'
 UNVERSIONED_INPUTS_ROOT = COVID_19 / 'unversioned-inputs'
 VACCINE_COVERAGE_OUTPUT_ROOT = COVID_19 / 'vaccine-coverage'
-VACCINE_EFFICACY_OUTPUT_ROOT = COVID_19 / 'vaccine-efficacy'
 VARIANT_OUTPUT_ROOT = COVID_19 / 'variant-scaleup'
 VISIT_VOLUME_ROOT = COVID_19 / 'visit-volume/'
+WANING_IMMUNITY_OUTPUT_ROOT = COVID_19 / 'waning-immunity'
 WEBSCRAPER_ROOT = COVID_19 / 'webscrape'
 
 
